Module blaxel.models.store_function_parameter
=============================================

Classes
-------

`StoreFunctionParameter(description: blaxel.types.Unset | str = <blaxel.types.Unset object>, name: blaxel.types.Unset | str = <blaxel.types.Unset object>, required: blaxel.types.Unset | bool = <blaxel.types.Unset object>, type_: blaxel.types.Unset | str = <blaxel.types.Unset object>)`
:   Store function parameter
    
    Attributes:
        description (Union[Unset, str]): Store function parameter description
        name (Union[Unset, str]): Store function parameter name
        required (Union[Unset, bool]): Store function parameter required
        type_ (Union[Unset, str]): Store function parameter type
    
    Method generated by attrs for class StoreFunctionParameter.

    ### Static methods

    `from_dict(src_dict: dict[str, typing.Any]) ‑> ~T`
    :

    ### Instance variables

    `additional_keys: list[str]`
    :

    `additional_properties: dict[str, typing.Any]`
    :

    `description: blaxel.types.Unset | str`
    :

    `name: blaxel.types.Unset | str`
    :

    `required: blaxel.types.Unset | bool`
    :

    `type_: blaxel.types.Unset | str`
    :

    ### Methods

    `to_dict(self) ‑> dict[str, typing.Any]`
    :